@@ -36,6 +36,7 @@ define("profile", default="profiles.config", type=str, help="配置文件")
 define("port", default="8080", type=int, help="服务监听端口")
 define("handler_path", default="handlers", type=str, help="处理器文件存储路径")
 define("echo_sql", default=True, type=bool, help="是否启用SQL输出")
+define("async_enable", default=True, type=bool, help="是否启用异步")
 define("max_limit", default=500, type=int, help="单次查询最大数量")
 # 日志初始化配置，配置文件中可修改设置
 options.logging = "DEBUG"
@@ -44,6 +45,7 @@ options.log_file_prefix = "log"
 options.log_rotate_when = "D"
 # options.log_rotate_interval,
 options.log_file_num_backups = 30
+options.async_enable = True
 
 
 class LogFormatter(TornadoLogFormatter):
@@ -102,7 +104,10 @@ class WebServer:
         tornado.options.parse_command_line()  # 2、调用tornado的命令行参数解析
         init_log()  # 3、初始化日志配置，要在命令行解析参数后，确保日志参数都已经设置完成。
         # 4、启动时创建数据库连接池
-        tornado.ioloop.IOLoop.current().run_sync(InitConnectionPool.create_pool)
+        if options.async_enable:
+            tornado.ioloop.IOLoop.current().run_sync(InitConnectionPool.create_pool)
+        else:
+            InitConnectionPool.sync_create_pool()
         # 5、自动化注册Handler处理类，
         self.autoRegisterHandler(f"{os.path.abspath(os.path.dirname(sys.argv[0]))}/{options.handler_path}",
                                  options.handler_path)
